local math = require("math")
local table = table or require "table"

local EDIBLE_CATEGORY = {
["FOOD_CATEGORY"] = true, 
["GRAIN_CATEGORY"] = true,
["FLOUR_CATEGORY"] = true, 
-- ["HAY_CATEGORY"] = true, 
["HERBS_CATEGORY"] = true,
["OAT_CATEGORY"] = true,
["DRESS_CATEGORY"] = true,
["ALCOHOL_CATEGORY"] = true,
["FLAX_CATEGORY"] = true,
}

function pbox_WildlifeTryRaid(a, buildings, maxEatAmount)
	local buildingSelect = math.random(1,#buildings)
	local building = buildings[buildingSelect]
	
	if building then
		local buildingResources = resourceMapToSortedList(building:getResourceMap(), true)
		if #buildingResources >= 1 then
			local resourceName = ""
			local resourceCount = 0
			
			if a.name =="Wolf" then
				resourceName = "meat"
				resourceCount = building:getResourceFree("meat")
			else
				-- this is basically "look in box X of Y and if there's no food in there, i'm outta here"
				local randomIndex = math.random(1,#buildingResources)
				
				resourceName = buildingResources[randomIndex].name
				local limitCategory = getResourceCfg(resourceName).limitCategory
				
				if EDIBLE_CATEGORY[limitCategory] then
					resourceCount = building:getResourceFree(resourceName)
				end	
			end
			
			if resourceCount > 0 then
			
				local eatCount = math.min(resourceCount, maxEatAmount)
				if canWalkToBuilding(a, building) then
					goToBuildingWithAnimation(a, building, getRandAnimation(a:getAnimations("walk")))
					a:addTaskPlayAnimationOnce(getRandAnimation(a:getAnimations("eat")))
					a:addTaskRemoveResourceFromBuilding(building, resourceName, eatCount)
					a:addTaskPlayAnimation(getRandAnimation(a:getAnimations("stay")))
					a:addTaskWait(5000)
					--LogUI(a.name .. " will eat " .. eatCount ..  " " .. resourceName)

					local data = {}
					data["buildingUid"] = building.uid
					data["resourceName"] = resourceName
					data["resourceCount"] = eatCount
					a:addTaskScript("pbox_WildlifeEatStuffAlarmTask", data)
					
					return
				end
			end	
		end
	end
end

function pbox_WildlifeRaidBuilding(a, maxEatAmount)
	local BUILDING_HOUSE = fv.core.BUILDING_HOUSE
	local BUILDING_STORAGE = fv.core.BUILDING_STORAGE
	local houses = findBuildingsWithClass(a.pos, a.cfg.visionRadius, BUILDING_HOUSE)
	local storages = findBuildingsWithClass(a.pos, a.cfg.visionRadius, BUILDING_STORAGE)

	if #storages >= 1 then
		pbox_WildlifeTryRaid(a, storages, maxEatAmount)
	elseif #houses >= 1 then
		pbox_WildlifeTryRaid(a, houses, maxEatAmount)
	end	
end

function pbox_WildlifeRaidHouse(a, maxEatAmount)
	local BUILDING_HOUSE = fv.core.BUILDING_HOUSE
	local houses = findBuildingsWithClass(a.pos, a.cfg.visionRadius, BUILDING_HOUSE)
	
	if #houses >= 1 then
		pbox_WildlifeTryRaid(a, houses, maxEatAmount)
	end	
end

function pbox_WildlifeRaidStorage(a, maxEatAmount)
	local BUILDING_STORAGE = fv.core.BUILDING_STORAGE
	local storages = findBuildingsWithClass(a.pos, a.cfg.visionRadius, BUILDING_STORAGE)
	
	if #storages >= 1 then
		pbox_WildlifeTryRaid(a, storages, maxEatAmount)
	end	
end